@@ -9,27 +9,25 @@
 #include "calendarview_debug.h"
 #include "helper.h"
 
-#include <CalendarSupport/Utils>
+#include <Akonadi/CalendarUtils>
+
+#include <QSharedPointer>
 
 using namespace EventViews;
 
-ViewCalendar::~ViewCalendar()
-{
-}
+ViewCalendar::~ViewCalendar() = default;
 
-MultiViewCalendar::~MultiViewCalendar()
-{
-}
+MultiViewCalendar::~MultiViewCalendar() = default;
 
 KCalendarCore::Calendar::Ptr MultiViewCalendar::getCalendar() const
 {
-    return KCalendarCore::Calendar::Ptr();
+    return {};
 }
 
 KCalendarCore::Incidence::List MultiViewCalendar::incidences() const
 {
     KCalendarCore::Incidence::List list;
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->getCalendar()) {
             list += cal->getCalendar()->incidences();
         }
@@ -44,22 +42,22 @@ int MultiViewCalendar::calendars() const
 
 ViewCalendar::Ptr MultiViewCalendar::findCalendar(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->isValid(incidence)) {
             return cal;
         }
     }
-    return ViewCalendar::Ptr();
+    return {};
 }
 
 ViewCalendar::Ptr MultiViewCalendar::findCalendar(const QString &incidenceIdentifier) const
 {
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->isValid(incidenceIdentifier)) {
             return cal;
         }
     }
-    return ViewCalendar::Ptr();
+    return {};
 }
 
 void MultiViewCalendar::addCalendar(const ViewCalendar::Ptr &calendar)
@@ -85,7 +83,7 @@ QString MultiViewCalendar::displayName(const KCalendarCore::Incidence::Ptr &inci
     if (cal) {
         return cal->displayName(incidence);
     }
-    return QString();
+    return {};
 }
 
 QString MultiViewCalendar::iconForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -94,19 +92,19 @@ QString MultiViewCalendar::iconForIncidence(const KCalendarCore::Incidence::Ptr
     if (cal) {
         return cal->iconForIncidence(incidence);
     }
-    return QString();
+    return {};
 }
 
 bool MultiViewCalendar::isValid(const KCalendarCore::Incidence::Ptr &incidence) const
 {
     ViewCalendar::Ptr cal = findCalendar(incidence);
-    return cal;
+    return !cal.isNull();
 }
 
 bool MultiViewCalendar::isValid(const QString &incidenceIdentifier) const
 {
     ViewCalendar::Ptr cal = findCalendar(incidenceIdentifier);
-    return cal;
+    return !cal.isNull();
 }
 
 QColor MultiViewCalendar::resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -124,12 +122,10 @@ Akonadi::Item MultiViewCalendar::item(const KCalendarCore::Incidence::Ptr &incid
         return mETMCalendar->item(incidence);
     }
 
-    return Akonadi::Item();
+    return {};
 }
 
-AkonadiViewCalendar::~AkonadiViewCalendar()
-{
-}
+AkonadiViewCalendar::~AkonadiViewCalendar() = default;
 
 bool AkonadiViewCalendar::isValid(const KCalendarCore::Incidence::Ptr &incidence) const
 {
@@ -155,7 +151,7 @@ bool AkonadiViewCalendar::isValid(const QString &incidenceIdentifier) const
 Akonadi::Item AkonadiViewCalendar::item(const KCalendarCore::Incidence::Ptr &incidence) const
 {
     if (!mCalendar || !incidence) {
-        return Akonadi::Item();
+        return {};
     }
     bool ok = false;
     Akonadi::Item::Id id = incidence->customProperty("VOLATILE", "AKONADI-ID").toLongLong(&ok);
@@ -166,7 +162,7 @@ Akonadi::Item AkonadiViewCalendar::item(const KCalendarCore::Incidence::Ptr &inc
         if (id == -1) {
             // Ok, we really don't know the ID, give up.
             qCWarning(CALENDARVIEW_LOG) << "Item is invalid. uid = " << incidence->instanceIdentifier();
-            return Akonadi::Item();
+            return {};
         }
         return mCalendar->item(incidence->instanceIdentifier());
     }
@@ -175,7 +171,7 @@ Akonadi::Item AkonadiViewCalendar::item(const KCalendarCore::Incidence::Ptr &inc
 
 QString AkonadiViewCalendar::displayName(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    return CalendarSupport::displayName(mCalendar.data(), item(incidence).parentCollection());
+    return Akonadi::CalendarUtils::displayName(mCalendar.data(), item(incidence).parentCollection());
 }
 
 QColor AkonadiViewCalendar::resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const
