@@ -11,17 +11,17 @@
 #include "timelineitem.h"
 #include "timelineview_p.h"
 
-#include <KGantt/KGanttAbstractRowController>
-#include <KGantt/KGanttDateTimeGrid>
-#include <KGantt/KGanttGraphicsItem>
-#include <KGantt/KGanttGraphicsView>
-#include <KGantt/KGanttItemDelegate>
-#include <KGantt/KGanttStyleOptionGanttItem>
+#include <KGanttAbstractRowController>
+#include <KGanttDateTimeGrid>
+#include <KGanttGraphicsItem>
+#include <KGanttGraphicsView>
+#include <KGanttItemDelegate>
+#include <KGanttStyleOptionGanttItem>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/ETMCalendar>
 #include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
-#include <CalendarSupport/Utils>
 
 #include "calendarview_debug.h"
 
@@ -159,7 +159,11 @@ private:
 
         QBrush brush = defaultBrush(type);
         if (opt.state & QStyle::State_Selected) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             QLinearGradient selectedGrad(0., 0., 0., QApplication::fontMetrics().height());
+#else
+            QLinearGradient selectedGrad(0., 0., 0., QFontMetricsF(painter->font()).height());
+#endif
             selectedGrad.setColorAt(0., Qt::red);
             selectedGrad.setColorAt(1., Qt::darkRed);
 
@@ -310,12 +314,12 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
         for (const Akonadi::Collection &collection : collections) {
             if (collection.contentMimeTypes().contains(Event::eventMimeType())) {
                 auto item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
-                d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << CalendarSupport::displayName(calendar().data(), collection)));
+                d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << Akonadi::CalendarUtils::displayName(calendar().data(), collection)));
                 const QColor resourceColor = EventViews::resourceColor(collection, preferences());
                 if (resourceColor.isValid()) {
                     item->setColor(resourceColor);
                 }
-                qCDebug(CALENDARVIEW_LOG) << "Created item " << item << " (" << CalendarSupport::displayName(calendar().data(), collection) << ") "
+                qCDebug(CALENDARVIEW_LOG) << "Created item " << item << " (" << Akonadi::CalendarUtils::displayName(calendar().data(), collection) << ") "
                                           << "with index " << index - 1 << " from collection " << collection.id();
                 d->mCalendarItemMap.insert(collection.id(), item);
             }
