@@ -269,7 +269,9 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                         "flat list instead of a hierarchical tree; the parental "
                                         "relationships are removed in the display."));
 
-    connect(mFlatViewButton, &QToolButton::toggled, this, [=](bool flatView) {setFlatView(flatView, true);});
+    connect(mFlatViewButton, &QToolButton::toggled, this, [=](bool flatView) {
+        setFlatView(flatView, true);
+    });
     if (mFullViewButton) {
         connect(mFullViewButton, &QToolButton::toggled, this, &TodoView::setFullView);
     }
@@ -600,6 +602,10 @@ void TodoView::updateConfig()
         mQuickAdd->setVisible(preferences()->enableQuickTodo());
     }
 
+    if (mProxyModel) {
+        mProxyModel->invalidate();
+    }
+
     updateView();
 }
 
@@ -955,7 +961,6 @@ void TodoView::setStartDate(QDate date)
     }
 }
 
-
 void TodoView::setNewPercentage(QAction *action)
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
